@@ -17,20 +17,27 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
  
-    $Id: Gain.h,v 1.1 2006/06/20 19:16:42 r_sijrier Exp $
+    $Id: Gain.h,v 1.13 2007/11/27 20:20:42 r_sijrier Exp $
 */
 
 #ifndef GAIN_H
 #define GAIN_H
 
 #include "Command.h"
+#include <QPoint>
 
 class ContextItem;
+class SongView;
+
 
 class Gain : public Command
 {
+	Q_OBJECT
+	Q_CLASSINFO("increase_gain", tr("Increase"));
+	Q_CLASSINFO("decrease_gain", tr("Decrease"));
+	
 public :
-        Gain(ContextItem* context, float gain = -1.0);
+        Gain(ContextItem* context, SongView* sv, QVariantList args);
         ~Gain();
 
         int begin_hold();
@@ -38,14 +45,27 @@ public :
         int prepare_actions();
         int do_action();
         int undo_action();
+        void cancel_action();
 
+        
         int jog();
+        
+        void set_cursor_shape(int useX, int useY);
 
 private :
 	ContextItem*	gainObject;
+	SongView*	m_sv;
         float 		origGain;
         float 		newGain;
-        int 		origY;
+        QPoint 		origPos;
+	QPoint		mousePos;
+	bool		horiz;
+	
+	int get_gain_from_object(float& gain);
+	
+public slots:
+        void increase_gain(bool autorepeat);
+        void decrease_gain(bool autorepeat);
 };
 
 #endif
