@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
  
-    $Id: Import.h,v 1.1 2006/04/20 14:51:13 r_sijrier Exp $
+    $Id: Import.h,v 1.8 2007/09/28 18:33:43 r_sijrier Exp $
 */
 
 #ifndef IMPORT_H
@@ -26,22 +26,37 @@
 #include "Command.h"
 
 class QString;
+class AudioClip;
+class ReadSource;
 
 class Import : public Command
 {
 public :
-        Import(Track* track);
-        Import(Track* track, QString fileName);
+	Import(const QString& fileName);
+	Import(Track* track, const TimeRef& length, bool silent = false);
+        Import(Track* track, const QString& fileName);
+        Import(Track* track, const QString& fileName, const TimeRef& position);
         ~Import();
 
         int prepare_actions();
         int do_action();
         int undo_action();
+	
+	int create_readsource();
+	void create_audioclip();
+	void set_track(Track* track);
+	void set_position(const TimeRef& position);
 
 private :
         Track* 		m_track;
         AudioClip*	m_clip;
+	ReadSource* 	m_source;
         QString 	m_fileName;
+	QString		m_name;
+	bool		m_silent;
+	TimeRef		m_initialLength;
+	bool		m_hasPosition;
+	TimeRef		m_position;
 };
 
 #endif
