@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
  
-    $Id: MoveEdge.h,v 1.2 2006/06/29 22:38:08 r_sijrier Exp $
+    $Id: MoveEdge.h,v 1.9 2007/08/31 09:19:51 r_sijrier Exp $
 */
 
 #ifndef MOVEEDGE_H
@@ -29,15 +29,18 @@
 
 class AudioClip;
 class Song;
+class SongView;
+class AudioClipView;
 
 class MoveEdge : public Command
 {
 public :
-        MoveEdge(AudioClip* clip, QByteArray whichEdge);
+        MoveEdge(AudioClipView* cv, SongView* sv, QByteArray whichEdge);
         ~MoveEdge();
 
         int begin_hold();
         int finish_hold();
+	void cancel_action();
         int prepare_actions();
         int do_action();
         int undo_action();
@@ -47,9 +50,12 @@ public :
 private :
         AudioClip* 	m_clip;
         Song*		m_song;
+	AudioClipView*	m_cv;
+	SongView*	m_sv;
         QByteArray	m_edge;
-        nframes_t	m_originalPos;
-        nframes_t	m_newPos;
+        TimeRef		m_originalPos;
+	TimeRef		m_newPos;
+	TimeRef		m_otherEdgePos;
 };
 
 #endif
