@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006 Remon Sijrier 
+    Copyright (C) 2005-2007 Remon Sijrier 
  
     This file is part of Traverso
  
@@ -17,35 +17,36 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
  
-    $Id: RemoveClip.h,v 1.1 2006/05/01 21:18:17 r_sijrier Exp $
 */
 
-#ifndef REMOVECLIP_H
-#define REMOVECLIP_H
+#ifndef REMOVE_CLIP_H
+#define REMOVE_CLIP_HS
 
 #include "Command.h"
 
-#include <QList>
-
 class AudioClip;
-class AudioClipManager;
+class Track;
 
-class RemoveClip : public Command
+class AddRemoveClip : public Command
 {
 public :
-        RemoveClip(AudioClip* clip);
-        RemoveClip(QList<AudioClip* > clips, AudioClipManager* manager);
-        ~RemoveClip();
-
-        int prepare_actions();
-        int do_action();
-        int undo_action();
+	AddRemoveClip(AudioClip* clip, int type);
+	~AddRemoveClip() {};
+	
+	enum {
+		ADD,
+		REMOVE
+	};
 
+	int prepare_actions();
+	int do_action();
+	int undo_action();
+	
 private :
-        QList<AudioClip* >		m_clips;
-
+	int m_type;
+	bool m_removeFromDataBase;
+	AudioClip* m_clip;
+	Track* m_track;
 };
 
 #endif
- 
- 
