@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006 Remon Sijrier 
+    Copyright (C) 2005-2007 Remon Sijrier 
  
     This file is part of Traverso
  
@@ -17,7 +17,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
  
-    $Id: SplitClip.h,v 1.1 2006/04/20 14:51:13 r_sijrier Exp $
 */
 
 #ifndef SPLITCLIPACTION_H
@@ -27,27 +26,37 @@
 #include "defines.h"
 
 class AudioClip;
-class Song;
 class Track;
+class SongView;
+class AudioClipView;
+class LineView;
 
 class SplitClip : public Command
 {
 public :
-        SplitClip(Song* song, AudioClip* clip);
-        ~SplitClip();
+	SplitClip(AudioClipView* view);
+        ~SplitClip() {};
 
         int prepare_actions();
         int do_action();
         int undo_action();
 
+	int begin_hold();
+	int finish_hold();
+	void cancel_action();
+	void set_cursor_shape(int useX, int useY);
+
+	int jog();
+	
 private :
-        Song* m_song;
+	SongView* m_sv;
+	AudioClipView* m_cv;
         Track* m_track;
         AudioClip* m_clip;
         AudioClip* leftClip;
         AudioClip* rightClip;
-        nframes_t	splitPoint;
-
+	TimeRef m_splitPoint;
+	LineView* m_splitcursor;
 };
 
 #endif
