@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
  
-    $Id: TrackPan.h,v 1.1 2006/04/20 14:51:13 r_sijrier Exp $
+    $Id: TrackPan.h,v 1.7 2007/04/25 05:43:36 benjie Exp $
 */
 
 #ifndef TRACKPAN_H
@@ -31,19 +31,22 @@ class Track;
 class TrackPan : public Command
 {
 public :
-        TrackPan(Track* track, Song* song);
-        ~TrackPan();
+	TrackPan(Track* track, QVariantList args);
 
         int begin_hold();
         int finish_hold();
         int prepare_actions();
         int do_action();
         int undo_action();
+        void cancel_action();
 
         int jog();
 
+	void set_cursor_shape(int useX, int useY);
+	
 private :
-        float origPan;
+	QPoint	mousePos;
+	float origPan;
         float newPan;
         int origX;
 
