@@ -17,21 +17,22 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
  
-    $Id: Zoom.h,v 1.1 2006/04/20 14:51:13 r_sijrier Exp $
+    $Id: Zoom.h,v 1.5 2007/01/16 20:21:08 r_sijrier Exp $
 */
 
 #ifndef ZOOM_H
 #define ZOOM_H
 
-#include <libtraversocore.h>
+#include "Command.h"
 
 class SongView;
+class QPoint;
 
 class Zoom : public Command
 {
 public :
         Zoom(SongView* sv);
-        ~Zoom();
+        ~Zoom() {};
 
         int begin_hold();
         int finish_hold();
@@ -41,14 +42,16 @@ public :
 
         int jog();
 
+        void set_cursor_shape(int useX, int useY);
+
 private :
         int origZoomLevel;
         int jogZoomTotalX;
-        int jogZoomTotalY;
         int lastJogZoomXFactor;
         int baseJogZoomXFactor;
         int verticalJogZoomLastY;
-
+	QPoint		mousePos;
+	
         SongView* m_sv;
 };
 
