@@ -1,15 +1,15 @@
 #include "SplitClip.h"
 #include "MoveClip.h"
 #include "MoveEdge.h"
-#include "CopyClip.h"
 #include "TrackPan.h"
-#include "Crop.h"
 #include "Zoom.h"
 #include "Import.h"
-#include "Shuttle.h"
 #include "PCommand.h"
 #include "ClipSelection.h"
-#include "RemoveClip.h"
 #include "Fade.h"
-#include "RemoveTrack.h"
 #include "Gain.h"
+#include "CommandGroup.h"
+#include "AddRemove.h"
+#include "AudioClipExternalProcessing.h"
+#include "ArmTracks.h"
+#include "RemoveClip.h"
