@@ -17,25 +17,28 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
  
-    $Id: AudioClipManager.cpp,v 1.5.2.1 2006/07/31 12:14:15 r_sijrier Exp $
+    $Id: AudioClipManager.cpp,v 1.20 2007/11/05 15:49:29 r_sijrier Exp $
 */
  
 #include "AudioClipManager.h"
 
 #include "Song.h"
 #include "AudioClip.h"
+#include "ResourcesManager.h"
+#include "ProjectManager.h"
 #include "Track.h"
 #include "commands.h"
-
+#include "SnapList.h"
+#include "Utils.h"
 #include "Debugger.h"
 
 AudioClipManager::AudioClipManager( Song* song )
-		: ContextItem( (ContextItem*) 0, song )
+	: ContextItem(song)
 {
 	PENTERCONS;
 	m_song = song;
 	set_history_stack( m_song->get_history_stack() );
-	lastFrame = 0;
+	lastLocation = TimeRef();
 }
 
 AudioClipManager::~ AudioClipManager( )
@@ -45,42 +48,54 @@ AudioClipManager::~ AudioClipManager( )
 
 void AudioClipManager::add_clip( AudioClip * clip )
 {
+	PENTER;
+	if (m_clips.contains(clip)) {
+		PERROR("Trying to add clip %s, but it's already in my list!!", QS_C(clip->get_name()));
+		return;
+	}
+	
 	m_clips.append( clip );
 	
-	connect(clip, SIGNAL(trackEndFrameChanged()), this, SLOT(update_last_frame()));
+	connect(clip, SIGNAL(trackEndLocationChanged()), this, SLOT(update_last_frame()));
+	connect(clip, SIGNAL(positionChanged(Snappable*)), m_song->get_snap_list(), SLOT(mark_dirty(Snappable*)));
 	
+	m_song->get_snap_list()->mark_dirty(clip);
 	update_last_frame();
+	resources_manager()->mark_clip_added(clip);
 }
 
+void AudioClipManager::remove_clip( AudioClip * clip )
+{
+	PENTER;
+	disconnect(clip, SIGNAL(positionChanged(Snappable*)), m_song->get_snap_list(), SLOT(mark_dirty(Snappable*)));
+	if (m_clips.removeAll(clip) == 0) {
+		PERROR("Clip %s was not in my list, couldn't remove it!!", QS_C(clip->get_name()));
+		return;
+	}
+	
+	m_song->get_snap_list()->mark_dirty(clip);
+	update_last_frame();
+	resources_manager()->mark_clip_removed(clip);
+}
+
+
 void AudioClipManager::update_last_frame( )
 {
 	PENTER;
 	
-	lastFrame = 0;
+	lastLocation = TimeRef();
 	
 	foreach(AudioClip* clip, m_clips) {
-		if (clip->get_track_end_frame() >= lastFrame)
-			lastFrame = clip->get_track_end_frame();
+		if (clip->get_track_end_location() >= lastLocation)
+			lastLocation = clip->get_track_end_location();
 	}
 	
-	emit lastFramePositionChanged();
+	emit m_song->lastFramePositionChanged();
 }
 
-nframes_t AudioClipManager::get_last_frame( )
+const TimeRef& AudioClipManager::get_last_location() const
 {
-	return lastFrame;
-}
-
-nframes_t AudioClipManager::get_start_frame( )
-{
-	nframes_t startframe = UINT_MAX;
-	
-	foreach(AudioClip* clip, m_clips) {
-		if (clip->get_track_start_frame() < startframe)
-			startframe = clip->get_track_start_frame();
-	}
-	
-	return startframe;
+	return lastLocation;
 }
 
 void AudioClipManager::get_selected_clips_state( QList< AudioClip * > & list )
@@ -165,28 +180,31 @@ Command* AudioClipManager::select_all_clips()
 {
 	PENTER;
 	
-	return new ClipSelection(m_clips, this, "add_to_selection");
+	return new ClipSelection(m_clips, this, "add_to_selection", tr("Selection: Add Clip"));
 }
 
 Command* AudioClipManager::deselect_all_clips()
 {
 	PENTER;
 	
-	return new ClipSelection(m_clips, this, "remove_from_selection");
+	return new ClipSelection(m_clips, this, "remove_from_selection", tr("Selection: Remove Clip"));
 }
 
 Command* AudioClipManager::invert_clip_selection()
 {
 	PENTER;
 	
-	return new ClipSelection(m_clips, this, "toggle_selected");
+	return new ClipSelection(m_clips, this, "toggle_selected", tr("Selection: Invert"));
 }
 
 Command* AudioClipManager::delete_selected_clips()
 {
 	PENTER;
-	
-	return new RemoveClip(clipselection, this);
+	CommandGroup* group = new CommandGroup(this, tr("Remove Clip(s)"));
+	foreach(AudioClip* clip, clipselection) {
+		group->add_command(clip->get_track()->remove_clip(clip));
+	}
+	return group;
 }
 
 //eof
