@@ -17,7 +17,7 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 
-$Id: AudioClipManager.h,v 1.2.2.1 2006/07/31 12:14:15 r_sijrier Exp $
+$Id: AudioClipManager.h,v 1.7 2007/09/10 18:42:48 r_sijrier Exp $
 */
 
 #ifndef AUDIOCLIPMANAGER_H
@@ -34,6 +34,11 @@ class Song;
 class AudioClipManager : public ContextItem
 {
 	Q_OBJECT
+	Q_CLASSINFO("select_all_clips", tr("Select all"))
+	Q_CLASSINFO("deselect_all_clips", tr("Deselect all"))
+	Q_CLASSINFO("invert_clip_selection", tr("Invert"))
+	Q_CLASSINFO("delete_selected_clips", tr("Delete selected"))
+
 public:
 	AudioClipManager(Song* song);
 	~AudioClipManager();
@@ -43,18 +48,18 @@ public:
 
 	QList<AudioClip* >* get_clip_list();
 
-	nframes_t get_last_frame();
-	nframes_t get_start_frame();
+	const TimeRef& get_last_location() const;
 
 private:
 	QList<AudioClip* >		m_clips;
 	QList<AudioClip* >		clipselection;
 	Song*				m_song;
 	
-	nframes_t 			lastFrame;
+	TimeRef 			lastLocation;
 
 public slots:
 	void add_clip(AudioClip* clip);
+	void remove_clip(AudioClip* clip);
 	void select_clip(AudioClip* clip);
 	void toggle_selected(AudioClip* clip);
 	
@@ -66,9 +71,6 @@ public slots:
 	Command* deselect_all_clips();
 	Command* invert_clip_selection();
 	Command* delete_selected_clips();
-	
-signals:
-	void lastFramePositionChanged();
 };
 
 #endif
