@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2006 Nicola Doebelin
+Copyright (C) 2006-2007 Nicola Doebelin, Remon Sijrier
 
 This file is part of Traverso
 
@@ -17,43 +17,52 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 
-$Id: SnapList.h,v 1.1.2.1 2006/07/31 13:10:38 r_sijrier Exp $
 */
 
 #ifndef SNAPLIST_H
 #define SNAPLIST_H
 
+#include <QObject>
 #include <QList>
 
 #include "defines.h"
 
 class Song;
 class AudioClip;
+class Snappable;
 
-class SnapList
+class SnapList : public QObject
 {
+	Q_OBJECT
 
 public:
 	SnapList(Song* song);
-	~SnapList();
+	~SnapList() {};
 
-	int get_snap_value(int);
-	bool is_snap_value(int);
-	void update_snaplist(AudioClip *);
-	void update_snaplist();
-	int get_snap_diff(int);
+	TimeRef get_snap_value(const TimeRef& location);
+	bool is_snap_value(const TimeRef& location);
+	qint64 get_snap_diff(const TimeRef& location);
+	TimeRef next_snap_pos(const TimeRef& location);
+	TimeRef prev_snap_pos(const TimeRef& location);
+	
+	void set_range(const TimeRef& start, const TimeRef& end, int scalefactor);
 
 private:
-	Song* m_song;
-	QList<int> xposList;
-	QList<int> xposLut;
-	QList<bool> xposBool;
-	QList<AudioClip* > m_clips;
+	Song* 		m_song;
+	QList<TimeRef> 	m_xposList;
+	QList<TimeRef> 	m_xposLut;
+	QList<bool> 	m_xposBool;
+	bool		m_isDirty;
+	TimeRef		m_rangeStart;
+	TimeRef		m_rangeEnd;
+	qint64		m_scalefactor;
 
-	void process_snaplist();
+	void update_snaplist();
+
+public slots:
+	void mark_dirty(Snappable *item);
 };
 
-
 #endif
 
 /* EOF */
