@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2005-2006 Remon Sijrier 
+Copyright (C) 2005-2007 Remon Sijrier 
 
 This file is part of Traverso
 
@@ -17,7 +17,6 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 
-$Id: Track.h,v 1.13 2006/07/27 08:45:31 r_sijrier Exp $
 */
 
 
@@ -30,91 +29,61 @@ $Id: Track.h,v 1.13 2006/07/27 08:45:31 r_sijrier Exp $
 #include <QByteArray>
 
 #include "ContextItem.h"
-#include "AudioClipList.h"
+#include "GainEnvelope.h"
+#include "AudioProcessingItem.h"
 
 #include "defines.h"
 
 class AudioClip;
 class Song;
+class PluginChain;
+class Plugin;
 
-
-class Track : public ContextItem
+class Track : public ContextItem, public AudioProcessingItem
 {
 	Q_OBJECT
+	Q_CLASSINFO("mute", tr("Mute"))
+	Q_CLASSINFO("toggle_arm", tr("Record: On/Off"))
+	Q_CLASSINFO("solo", tr("Solo"))
+	Q_CLASSINFO("silence_others", tr("Silence other tracks"))
 
 public :
-	Track(Song* pParentSong, int pID, QString pName, int pBaseY, int pHeight);
+	Track(Song* song, const QString& name, int height);
 	Track(Song* song, const QDomNode node);
 	~Track();
 
 	static const int INITIAL_HEIGHT = 100;
-	static const int MINIMUM_HEIGHT = 25;
 
-	void activate();
-	void deactivate();
-	bool is_pointed(int y);
-	void set_blur(bool stat);
+	Command* add_clip(AudioClip* clip, bool historable=true, bool ismove=false);
+	Command* add_plugin(Plugin* plugin);
 
-	void add_clip(AudioClip* clip);
-
-	int remove_clip(AudioClip* clip);
+	Command* remove_clip(AudioClip* clip, bool historable=true, bool ismove=false);
+	Command* remove_plugin(Plugin* plugin);
+	
+	AudioClip* init_recording();
+	
 	int arm();
 	int disarm();
-	void toggle_active();
-
-	AudioClip* get_clip_under(nframes_t framePos);
-	AudioClip* get_clip_after(nframes_t framePos);
-	AudioClip* get_clip_before(nframes_t framePos);
-	AudioClip* get_clip_between(nframes_t framePosL, nframes_t framePosR);
-
-	QList<AudioClip* > split_clip(nframes_t splitPoint);
-	QList<AudioClip* > split_clip(AudioClip* c, nframes_t splitPoint);
-// 	int delete_clip(AudioClip* clip, bool permanently = 0);
-
-	void get_render_range(nframes_t& startframe, nframes_t& endframe);
-
 
 	// Get functions:
-	int get_id() const
-	{
-		return ID;
-	}
-	QString get_bus_in() const
-	{
-		return busIn;
-	}
-	QString get_bus_out() const
-	{
-		return busOut;
-	}
-	int get_baseY() const
-	{
-		return baseY;
-	}
-	int get_height() const
-	{
-		return height;
-	}
-	int real_baseY() const;
-	float get_pan() const
-	{
-		return m_pan;
-	}
-	Song* get_song() const
-	{
-		return m_song;
-	}
-	QString get_name() const
-	{
-		return m_name;
-	}
+	AudioClip* get_clip_after(const TimeRef& pos);
+	AudioClip* get_clip_before(const TimeRef& pos);
+	void get_render_range(TimeRef& startlocation, TimeRef& endlocation);
+	QString get_bus_in() const {return busIn;}
+	QString get_bus_out() const{return busOut;}
+	int get_height() const {return m_height;}
+	float get_pan() const {return m_pan;}
+	Song* get_song() const {return m_song;}
+	QString get_name() const {return m_name;}
+	
 	int get_total_clips();
-	QDomNode get_state(QDomDocument doc);
-	AudioClipList get_cliplist() const
-	{
-		return audioClipList;
-	}
-	// End get functions
+	QDomNode get_state(QDomDocument doc, bool istemplate=false);
+	PluginChain* get_plugin_chain() const {return m_pluginChain;}
+	APILinkedList& get_cliplist() {return m_clips;}
+	int get_sort_index() const;
+	bool is_smaller_then(APILinkedListNode* node) {return ((Track*)node)->get_sort_index() > get_sort_index();}
+
+	
 
 	// Set functions:
 	void set_bus_out(QByteArray bus);
@@ -124,49 +93,49 @@ public :
 	void set_solo(bool solo);
 	void set_muted(bool muted);
 	void set_pan(float pan);
-	void set_baseY(int b);
+	void set_sort_index(int index);
 	void set_height(int h);
+	void set_capture_left_channel(bool capture);
+	void set_capture_right_channel(bool capture);
 	int set_state( const QDomNode& node );
-	void set_id(int id);
-	// End set functions
 
 
 	//Bool functions:
-	bool is_muted();
 	bool is_muted_by_solo();
 	bool is_solo();
-	bool is_active();
 	bool armed();
+	bool capture_left_channel()
+	{
+		return m_captureLeftChannel;
+	}
+	bool capture_right_channel()
+	{
+		return m_captureRightChannel;
+	}
 	// End bool functions
 
 
-	void vzoom_in(int newBaseY);
-	void vzoom_out(int newBaseY);
-
 	int process(nframes_t nframes);
 
-
 private :
-	Song* m_song;
-	AudioClipList audioClipList;
+	Song*		m_song;
+	APILinkedList 	m_clips;
 
-	float m_gain;
-	float m_pan;
-	int ID;
+	float 	m_pan;
 	int numtakes;
 	QByteArray busIn;
 	QByteArray busOut;
 
 	QString m_name;
 
-	int baseY;
-	int height;
+	int m_sortIndex;
+	int m_height;
 
-	bool isActive;
 	bool isSolo;
-	bool isMuted;
 	bool isArmed;
 	bool mutedBySolo;
+	bool m_captureLeftChannel;
+	bool m_captureRightChannel;
 
 	void set_armed(bool armed);
 	void init();
@@ -179,24 +148,22 @@ signals:
 	void soloChanged(bool isSolo);
 	void armedChanged(bool isArmed);
 	void lockChanged(bool isLocked);
-	void isActiveChanged(bool isActive);
 	void gainChanged();
 	void panChanged();
 	void stateChanged();
 	void audibleStateChanged();
+	void inBusChanged();
+	void outBusChanged();
 
 public slots:
-	void init_recording();
 	void set_gain(float gain);
+	void clip_position_changed(AudioClip* clip);
 	
 	float get_gain() const;
 
 	Command* mute();
 	Command* toggle_arm();
 	Command* solo();
-	Command* gain();
-	Command* pan();
-	Command* import_audiosource();
 	Command* silence_others();
 
 private slots:
@@ -205,5 +172,11 @@ private slots:
 
 };
 
+
+inline float Track::get_gain( ) const
+{
+	return m_fader->get_gain();
+}
+
 #endif
 
