@@ -1,21 +1,27 @@
 #include "AudioClip.h"
 #include "AudioClipManager.h"
 #include "AudioSource.h"
-#include "AudioSourceManager.h"
+#include "ResourcesManager.h"
+#include "Command.h"
+#include "CommandPlugin.h"
 #include "ContextItem.h"
+#include "Config.h"
 #include "ContextPointer.h"
 #include "Curve.h"
-#include "IEAction.h"
+#include "CurveNode.h"
+#include "FadeCurve.h"
 #include "Information.h"
 #include "InputEngine.h"
+#include "Marker.h"
 #include "Mixer.h"
-#include "MtaRegion.h"
-#include "MtaRegionList.h"
 #include "Peak.h"
 #include "Project.h"
 #include "ProjectManager.h"
+#include "ReadSource.h"
+#include "SnapList.h"
 #include "Song.h"
+#include "TimeLine.h"
 #include "Track.h"
-#include "Tsar.h"
 #include "Utils.h"
-
+#include "ViewPort.h"
+#include "WriteSource.h"
