@@ -20,15 +20,13 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 
-$Id: AlsaDriver.cpp,v 1.5 2006/07/27 18:45:24 r_sijrier Exp $
+$Id: AlsaDriver.cpp,v 1.19 2007/12/03 16:24:20 r_sijrier Exp $
 */
 
 
 #include "AlsaDriver.h"
-#include "AudioDevice.h"
 #include "AudioChannel.h"
-
-#include <pthread.h>
+#include <Utils.h>
 
 #include <math.h>
 #include <stdio.h>
@@ -45,6 +43,8 @@ $Id: AlsaDriver.cpp,v 1.5 2006/07/27 18:45:24 r_sijrier Exp $
 #include <sys/time.h>
 #include <time.h>
 
+#include "AudioDevice.h"
+
 // Always put me below _all_ includes, this is needed
 // in case we run with memory leak detection enabled!
 #include "Debugger.h"
@@ -98,15 +98,11 @@ AlsaDriver::~AlsaDriver()
 }
 
 
-int AlsaDriver::setup()
+int AlsaDriver::setup(bool capture, bool playback, const QString& pcmName)
 {
-	unsigned long user_nperiods = 2;
-	char *playback_pcm_name = "hw:0";
-	char *capture_pcm_name = "hw:0";
-	int capture = false;
-	int playback = false;
-	int soft_mode = false;
-	int monitor = false;
+	unsigned long user_nperiods = device->get_driver_property("numberofperiods", 3).toInt();
+	char *playback_pcm_name = pcmName.toAscii().data();
+	char *capture_pcm_name = pcmName.toAscii().data();
 	int shorts_first = false;
 
 	/* duplex is the default */
@@ -121,6 +117,8 @@ int AlsaDriver::setup()
 	capture_handle = (snd_pcm_t*) 0;
 	ctl_handle = 0;
 	capture_and_playback_not_synced = false;
+	capture_interleaved = false;
+	playback_interleaved = false;
 	max_nchannels = 0;
 	user_nchannels = 0;
 	playback_nchannels = 0;
@@ -142,23 +140,14 @@ int AlsaDriver::setup()
 
 
 	silent = 0;
-	all_monitor_in = false;
-	with_monitor_ports = monitor;
-
-	input_monitor_mask = 0;   /* XXX is it? */
-
 
 	pfd = 0;
 	playback_nfds = 0;
 	capture_nfds = 0;
 
 	dither = None;
-	soft_mode = soft_mode;
+	soft_mode = false;
 
-	pthread_mutex_init (&clock_sync_lock, 0);
-
-	poll_late = 0;
-	xrun_count = 0;
 	process_count = 0;
 
 	alsa_name_playback = strdup (playback_pcm_name);
@@ -178,17 +167,17 @@ int AlsaDriver::setup()
 		if (snd_pcm_open (&playback_handle, alsa_name_playback, SND_PCM_STREAM_PLAYBACK, SND_PCM_NONBLOCK) < 0) {
 			switch (errno) {
 			case EBUSY:
-				printf ("ALSA Driver: The playback device \"%s\" is already in use. Please stop the"
-					" application using it and run Traverso again\n",  playback_pcm_name);
+				device->message(tr("ALSA Driver: The playback device %1 is already in use. Please stop the"
+					" application using it and run Traverso again").arg(playback_pcm_name), AudioDevice::INFO);
 				return -1;
 				break;
 
 			case EPERM:
-				printf ("ALSA Driver: You do not have permission to open the audio device \"%s\" for playback\n", playback_pcm_name);
+				device->message(tr("ALSA Driver: You do not have permission to open the audio device %1 for playback").arg(playback_pcm_name), AudioDevice::INFO);
 				return -1;
 				break;
 			default:
-				PERROR ("snd_pcm_open(playback_handle, ..) failed with unknown error type");
+				device->message(tr("snd_pcm_open(playback_handle, ..) failed with unknown error type"), AudioDevice::WARNING);
 			}
 
 			playback_handle = 0;
@@ -203,17 +192,17 @@ int AlsaDriver::setup()
 		if (snd_pcm_open (&capture_handle, alsa_name_capture, SND_PCM_STREAM_CAPTURE,  SND_PCM_NONBLOCK) < 0) {
 			switch (errno) {
 			case EBUSY:
-				PWARN ("ALSA Driver: The capture device \"%s\" is already in use. Please stop the"
-				" application using it and run Traverso again", capture_pcm_name);
+				device->message(tr("ALSA Driver: The capture device %1 is already in use. Please stop the"
+				" application using it and run Traverso again").arg(capture_pcm_name), AudioDevice::INFO);
 				return -1;
 				break;
 
 			case EPERM:
-				PWARN ("ALSA Driver: You do not have permission to open the audio device \"%s\" for capture", capture_pcm_name);
+				device->message(tr("ALSA Driver: You do not have permission to open the audio device %1 for capture").arg(capture_pcm_name), AudioDevice::WARNING);
 				return -1;
 				break;
 			default:
-				PERROR ("snd_pcm_open(capture_handle, ...) failed with unknown error type");
+				device->message(tr("ALSA Driver: snd_pcm_open(capture_handle, ...) failed with unknown error type"), AudioDevice::WARNING);
 			}
 
 			capture_handle = 0;
@@ -229,7 +218,7 @@ int AlsaDriver::setup()
 
 			/* they asked for playback, but we can't do it */
 
-			PWARN ("ALSA: Cannot open PCM device %s for playback. Falling back to capture-only mode", "alsa_pcm");
+			device->message(tr("ALSA Driver: Cannot open PCM device %1 for playback. Falling back to capture-only mode").arg("alsa_pcm"), AudioDevice::WARNING);
 
 			if (capture_handle == 0) {
 				/* can't do anything */
@@ -244,7 +233,7 @@ int AlsaDriver::setup()
 
 			/* they asked for capture, but we can't do it */
 
-			PWARN ("ALSA: Cannot open PCM device %s for capture. Falling back to playback-only mode", "alsa_pcm");
+			device->message(tr("ALSA: Cannot open PCM device %1 for capture. Falling back to playback-only mode").arg("alsa_pcm"), AudioDevice::WARNING);
 
 			if (playback_handle == 0) {
 				/* can't do anything */
@@ -279,6 +268,8 @@ int AlsaDriver::setup()
 		}
 	}
 
+	
+	
 	if (set_parameters (frames_per_cycle, user_nperiods, frame_rate)) {
 		return -1;
 	}
@@ -560,6 +551,7 @@ int AlsaDriver::configure_stream(char *device_name,
 
 	if ((err = snd_pcm_hw_params (handle, hw_params)) < 0) {
 		PERROR ("ALSA: cannot set hardware parameters for %s", stream_name);
+		device->message(tr("ALSA Driver: Unable to configure hardware, is it in use by another application?"), AudioDevice::WARNING);
 		return -1;
 	}
 
@@ -983,8 +975,9 @@ int AlsaDriver::stop()
 	be entering offline mode.
 	*/
 
-	foreach(AudioChannel* bus, captureChannels) {
-		buf = bus->get_buffer(frames_per_cycle);
+	for (int i=0; i<captureChannels.size(); ++i) {
+		AudioChannel* chan = captureChannels.at(i);
+		buf = chan->get_buffer(frames_per_cycle);
 		memset (buf, 0, sizeof (audio_sample_t) * frames_per_cycle);
 	}
 
@@ -1035,13 +1028,12 @@ int AlsaDriver::xrun_recovery (float *delayed_usecs)
 
 	if (snd_pcm_status_get_state(status) == SND_PCM_STATE_XRUN && process_count > XRUN_REPORT_DELAY) {
 		struct timeval now, diff, tstamp;
-		xrun_count++;
 		gettimeofday(&now, 0);
 		snd_pcm_status_get_trigger_tstamp(status, &tstamp);
 		timersub(&now, &tstamp, &diff);
 		*delayed_usecs = diff.tv_sec * 1000000.0 + diff.tv_usec;
 		printf ("\n**** alsa_pcm: xrun of at least %.3f msecs\n\n", *delayed_usecs / 1000.0);
-		emit device->xrun();
+		device->xrun();
 	}
 
 	if (restart()) {
@@ -1134,7 +1126,6 @@ again:
 			* a wakeup delay:
 			*/
 			poll_next = 0;
-			poll_late++;
 		}
 
 		device->transport_cycle_end(poll_enter);
@@ -1272,7 +1263,6 @@ again:
 	if (capture_handle) {
 		if ((capture_avail = snd_pcm_avail_update (capture_handle)) < 0) {
 			if (capture_avail == -EPIPE) {
-				PWARN("capture pipeerror, xrun_detected is true");
 				xrun_detected = true;
 			} else {
 				PERROR ("ALSA Driver: unknown avail_update return value (%ld)", capture_avail);
@@ -1286,7 +1276,6 @@ again:
 	if (playback_handle) {
 		if ((playback_avail = snd_pcm_avail_update (playback_handle)) < 0) {
 			if (playback_avail == -EPIPE) {
-				PWARN("playback pipeerror, xrun_detected is true");
 				xrun_detected = true;
 			} else {
 				PERROR ("ALSA Driver: unknown avail_update return value (%ld)", playback_avail);
@@ -1421,7 +1410,8 @@ int AlsaDriver::_read(nframes_t nframes)
 			return -1;
 		}
 
-		foreach(AudioChannel* channel, captureChannels) {
+		for (int i=0; i<captureChannels.size(); ++i) {
+			AudioChannel* channel = captureChannels.at(i);
 			
 			if (!channel->has_data()) {
 				//no-copy optimization
@@ -1454,6 +1444,10 @@ int AlsaDriver::_write(nframes_t nframes)
 
 	process_count++;
 
+	if (! playback_handle) {
+		return 0;
+	}
+	
 	if (nframes > frames_per_cycle) {
 		return -1;
 	}
@@ -1462,10 +1456,6 @@ int AlsaDriver::_write(nframes_t nframes)
 	contiguous = 0;
 	orig_nframes = nframes;
 
-	/* check current input monitor request status */
-
-	input_monitor_mask = 0;
-
 	while (nframes) {
 
 		contiguous = nframes;
@@ -1474,7 +1464,8 @@ int AlsaDriver::_write(nframes_t nframes)
 			return -1;
 		}
 
-		foreach(AudioChannel* channel, playbackChannels) {
+		for (int i=0; i<playbackChannels.size(); ++i) {
+			AudioChannel* channel = playbackChannels.at(i);
 			if (!channel->has_data()) {
 				continue;
 			}
@@ -1545,7 +1536,7 @@ int AlsaDriver::attach()
 
 		snprintf (buf, sizeof(buf) - 1, "capture_%lu", chn+1);
 
-		chan = device->register_capture_channel(buf, JACK_DEFAULT_AUDIO_TYPE, port_flags, frames_per_cycle, chn);
+		chan = device->register_capture_channel(buf, "32 bit float audio", port_flags, frames_per_cycle, chn);
 		chan->set_latency( frames_per_cycle + capture_frame_latency );
 		captureChannels.append(chan);
 
@@ -1557,13 +1548,12 @@ int AlsaDriver::attach()
 
 		snprintf (buf, sizeof(buf) - 1, "playback_%lu", chn+1);
 
-		chan = device->register_playback_channel(buf, JACK_DEFAULT_AUDIO_TYPE, port_flags, frames_per_cycle, chn);
+		chan = device->register_playback_channel(buf, "32 bit float audio", port_flags, frames_per_cycle, chn);
 		chan->set_latency( frames_per_cycle + capture_frame_latency );
 		playbackChannels.append(chan);
 	}
 
 
-	// 	return jack_activate (client);
 	return 1;
 }
 
@@ -1572,46 +1562,6 @@ int AlsaDriver::detach ()
 	return 0;
 }
 
-
-
-static int
-dither_opt (char c, DitherAlgorithm* dither)
-{
-	switch (c) {
-	case '-':
-	case 'n':
-		*dither = None;
-		break;
-
-	case 'r':
-		*dither = Rectangular;
-		break;
-
-	case 's':
-		*dither = Shaped;
-		break;
-
-	case 't':
-		*dither = Triangular;
-		break;
-
-	default:
-		fprintf (stderr, "ALSA driver: illegal dithering mode %c\n", c);
-		return -1;
-	}
-	return 0;
-}
-
-
-/* DRIVER "PLUGIN" INTERFACE */
-
-const char driver_client_name[] = "alsa_pcm";
-
-const char* get_descriptor ()
-{
-	return "";
-}
-
 QString AlsaDriver::get_device_name( )
 {
 	return alsa_device_name(false);
@@ -1622,40 +1572,35 @@ QString AlsaDriver::get_device_longname( )
 	return alsa_device_name(true);
 }
 
-QString AlsaDriver::alsa_device_name(bool longname)
+QString AlsaDriver::alsa_device_name(bool longname, int devicenumber)
 {
 	snd_ctl_card_info_t *info;
 	snd_ctl_t *handle;
 	char name[32];
-	sprintf(name, "hw:%d", 0);
+	sprintf(name, "hw:%d", devicenumber);
 	int err = 0;
 
 	snd_ctl_card_info_alloca(&info);
 
-	if ((err = snd_ctl_open(&handle, name, 0)) < 0) {
-		PERROR("Control open (%i): %s", 0, snd_strerror(err));
+	if ((err = snd_ctl_open(&handle, name, devicenumber)) < 0) {
+		PMESG("Control open (%i): %s", devicenumber, snd_strerror(err));
+		return "";
 	}
 
 	if ((err = snd_ctl_card_info(handle, info)) < 0) {
-		PERROR("Control hardware info (%i): %s", 0, snd_strerror(err));
+		PMESG("Control hardware info (%i): %s", 0, snd_strerror(err));
 	}
 
 	snd_ctl_close(handle);
 
-	if (err < 0)
+	if (err < 0) {
 		return "Device name unknown";
+	}
 
-	/*	int dev = -1;
-		if (snd_ctl_pcm_next_device(handle, &dev)<0)
-			PERROR("No buses available on soundcard :-(");
-		if (dev < 0)
-			return "";
-		
-		snd_pcm_info_set_device(pcminfo, dev);
-		snd_pcm_info_set_subdevice(pcminfo, 0);*/
 
-	if (longname)
+	if (longname) {
 		return snd_ctl_card_info_get_name(info);
+	}
 
 	return snd_ctl_card_info_get_id(info);
 }
