@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2005-2006 Remon Sijrier 
+Copyright (C) 2005-2006 Remon Sijrier
 
 This file is part of Traverso
 
@@ -17,7 +17,7 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 
-$Id: BusMonitor.h,v 1.2 2006/04/25 17:22:13 r_sijrier Exp $
+$Id: BusMonitor.h,v 1.7 2007/05/08 16:44:31 r_sijrier Exp $
 */
 
 #ifndef BUSMONITOR_H
@@ -25,32 +25,29 @@ $Id: BusMonitor.h,v 1.2 2006/04/25 17:22:13 r_sijrier Exp $
 
 #include <QWidget>
 #include <QList>
-#include <QHBoxLayout>
 
 class VUMeter;
-class Interface;
+class Project;
 
 class BusMonitor :  public QWidget
 {
 	Q_OBJECT
 
 public:
-	BusMonitor(QWidget* parent, Interface* interface);
+	BusMonitor(QWidget* parent);
 	~BusMonitor();
 
 protected:
-	void resizeEvent( QResizeEvent* e);
-
+	QSize sizeHint () const;
+	QSize minimumSizeHint () const;
+	
 private:
-	QHBoxLayout* 		layout;
-	QHBoxLayout* 		vumeterLayout;
-	QWidget* 			vumeterLayoutWidget;
-	QList<VUMeter* >		inMeters;
-	QList<VUMeter* >		outMeters;
-	Interface*				m_interface;
+	QList<VUMeter* >	inMeters;
+	QList<VUMeter* >	outMeters;
 
 private slots:
 	void create_vu_meters();
+	void set_project(Project* project);
 };
 
 #endif
